<!-- Auto-generated content start -->
# superduper_snowflake

Superduper snowflake is a vector search plugin for Superduper that allows you to performce vector search directly on snowflake tables.

## Installation

```bash
pip install superduper_snowflake
```

## API


- [Code](https://github.com/superduper-io/superduper/tree/main/plugins/snowflake)
- [API-docs](/docs/api/plugins/superduper_snowflake)

| Class | Description |
|---|---|
| `superduper_snowflake.vector_search.SnowflakeVectorSearch` | SnowflakeVectorSearch class for performing vector search. |



<!-- Auto-generated content end -->

<!-- Add your additional content below -->
